==> 1.2.0.tar.gz: test/src/api_test.dart <==
// Copyright (c) 2013, the project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed 
// by a Apache license that can be found in the LICENSE file.

part of handheld_test;

class ApiTest {
  ApiTest() {
    handheld.onDeviceReady.then((Device device) {
      group("handheld api test -", () {
        test("device ready", () {
          expect(device, isNotNull);
        });
        
        test("device info", () {
          expect(device.info.name, isNotNull);
          expect(device.info.platform, isNotNull);
          expect(device.info.platformVersion, isNotNull);
          expect(device.info.screen.width, equals(320));
        });
        
        test("get device acceleration", () {
          device.accelerometer.currentAcceleration.then(expectAsync1((DeviceAcceleration acceleration) {
            expect(acceleration.x, equals(1.0));
            expect(acceleration.y, equals(2.0));
            expect(acceleration.z, equals(3.0));
            expect(acceleration.timestamp, isNotNull);
          }));
        });
        
        test("watch device acceleration", () {
          Future<bool> streamTest() {
            var completer = new Completer<bool>();
            // test stream
            var stream = device.accelerometer.watchAcceleration(100);
            stream.listen((DeviceAcceleration acceleration) {
              stream.close();
              completer.complete(true);
            });
            return completer.future;
          }
          expect(streamTest(), completion(equals(true)));
        });
      });
    });
  }
}

==> 2.0.0.tar.gz: test/src/api_test.dart <==
// Copyright (c) 2013, the project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed 
// by a Apache license that can be found in the LICENSE file.

part of handheld_test;

class ApiTest {
  ApiTest() {
    handheld.onDeviceReady.then((Device device) {
      group("handheld api test -", () {
        test("device ready", () {
          expect(device, isNotNull);
        });
        
        test("device info", () {
          expect(device.info.name, isNotNull);
          expect(device.info.platform, isNotNull);
          expect(device.info.platformVersion, isNotNull);
          expect(device.info.screen.width, equals(320));
        });
        
        test("device camera", () {
          device.camera.getPictureUri().then(expectAsync((Uri uri) {
            expect(uri.toString(), equals("http://google.com/images/srpr/logo4w.png"));
          }));
          device.camera.getPictureData().then(expectAsync((String data) {
            expect(data, isNot(isEmpty));
          }));
          expect(device.camera.cleanup(), completion(isTrue));
        });
        
        test("device database", () {
          
        });
        
        test("device acceleration", () {
          device.accelerometer.currentAcceleration.then(expectAsync((DeviceAcceleration acceleration) {
            expect(acceleration.x, equals(1.0));
            expect(acceleration.y, equals(2.0));
            expect(acceleration.z, equals(3.0));
            expect(acceleration.timestamp, isNotNull);
          }));
        });
        
        test("device acceleration watch", () {
          Future<bool> streamTest() {
            var completer = new Completer<bool>();
            // test stream
            var stream = device.accelerometer.watchAcceleration(100);
            stream.listen((DeviceAcceleration acceleration) {
              stream.close();
              completer.complete(true);
            });
            return completer.future;
          }
          expect(streamTest(), completion(equals(true)));
        });
        
        skip_test("device notification", () {
          
        });
      });
    });
  }
}
